function [acceleration]=acceleration_slope_response(percent,max_ang,gravity)
%ACCELERATION_SLOPE_RESPONSE Esta funpção calcula qual é a aceleração a
%                            impor ao veículo derivado da acção da
%                            gravidade.
%##########################################################################
% A função aceita como inputs o valor da gravidade, a percentagem de slope
% (entre 0 e 1) e o angulo máximo (em módulo) desde um set point.
%
% INPUTS:
% percent -> Valor entre 0 e 1, que serve de constante de
%            proporcionalidade;
% max_ang -> Módulo do offset máximo do valor angular de slope [deg].
% gravity -> Aceleração da gravidade [m/s²]
%
% OUTPUTS:
% acceleration -> Valor da aceleração a impor, em [m/s²].
%##########################################################################
% Cálculo e normalização do angulo theta:
theta_real=(2*max_ang)*percent-max_ang;
% Calculo da aceleração a impôr ao veículo:
acceleration=-gravity*sind(theta_real);
end